==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/RequestOutputItem.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RequestOutputItem(
    dashPlaylistSettings: Option[
      zio.aws.mediatailor.model.DashPlaylistSettings
    ] = None,
    hlsPlaylistSettings: Option[zio.aws.mediatailor.model.HlsPlaylistSettings] =
      None,
    manifestName: __string,
    sourceGroup: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.RequestOutputItem = {
    import RequestOutputItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
      .builder()
      .optionallyWith(dashPlaylistSettings.map(value => value.buildAwsValue()))(
        _.dashPlaylistSettings
      )
      .optionallyWith(hlsPlaylistSettings.map(value => value.buildAwsValue()))(
        _.hlsPlaylistSettings
      )
      .manifestName(__string.unwrap(manifestName): java.lang.String)
      .sourceGroup(__string.unwrap(sourceGroup): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.RequestOutputItem.ReadOnly =
    zio.aws.mediatailor.model.RequestOutputItem.wrap(buildAwsValue())
}
object RequestOutputItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.RequestOutputItem =
      zio.aws.mediatailor.model.RequestOutputItem(
        dashPlaylistSettings.map(value => value.asEditable),
        hlsPlaylistSettings.map(value => value.asEditable),
        manifestName,
        sourceGroup
      )
    def dashPlaylistSettings
        : Option[zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly]
    def hlsPlaylistSettings
        : Option[zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly]
    def manifestName: __string
    def sourceGroup: __string
    def getDashPlaylistSettings: ZIO[
      Any,
      AwsError,
      zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly
    ] = AwsError.unwrapOptionField("dashPlaylistSettings", dashPlaylistSettings)
    def getHlsPlaylistSettings: ZIO[
      Any,
      AwsError,
      zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly
    ] = AwsError.unwrapOptionField("hlsPlaylistSettings", hlsPlaylistSettings)
    def getManifestName: ZIO[Any, Nothing, __string] = ZIO.succeed(manifestName)
    def getSourceGroup: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ) extends zio.aws.mediatailor.model.RequestOutputItem.ReadOnly {
    override val dashPlaylistSettings
        : Option[zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly] =
      scala
        .Option(impl.dashPlaylistSettings())
        .map(value =>
          zio.aws.mediatailor.model.DashPlaylistSettings.wrap(value)
        )
    override val hlsPlaylistSettings
        : Option[zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly] = scala
      .Option(impl.hlsPlaylistSettings())
      .map(value => zio.aws.mediatailor.model.HlsPlaylistSettings.wrap(value))
    override val manifestName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.manifestName())
    override val sourceGroup: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceGroup())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ): zio.aws.mediatailor.model.RequestOutputItem.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/RequestOutputItem.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RequestOutputItem(
    dashPlaylistSettings: Option[
      zio.aws.mediatailor.model.DashPlaylistSettings
    ] = None,
    hlsPlaylistSettings: Option[zio.aws.mediatailor.model.HlsPlaylistSettings] =
      None,
    manifestName: __string,
    sourceGroup: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.RequestOutputItem = {
    import RequestOutputItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
      .builder()
      .optionallyWith(dashPlaylistSettings.map(value => value.buildAwsValue()))(
        _.dashPlaylistSettings
      )
      .optionallyWith(hlsPlaylistSettings.map(value => value.buildAwsValue()))(
        _.hlsPlaylistSettings
      )
      .manifestName(manifestName: java.lang.String)
      .sourceGroup(sourceGroup: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.RequestOutputItem.ReadOnly =
    zio.aws.mediatailor.model.RequestOutputItem.wrap(buildAwsValue())
}
object RequestOutputItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.RequestOutputItem =
      zio.aws.mediatailor.model.RequestOutputItem(
        dashPlaylistSettings.map(value => value.asEditable),
        hlsPlaylistSettings.map(value => value.asEditable),
        manifestName,
        sourceGroup
      )
    def dashPlaylistSettings
        : Option[zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly]
    def hlsPlaylistSettings
        : Option[zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly]
    def manifestName: __string
    def sourceGroup: __string
    def getDashPlaylistSettings: ZIO[
      Any,
      AwsError,
      zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly
    ] = AwsError.unwrapOptionField("dashPlaylistSettings", dashPlaylistSettings)
    def getHlsPlaylistSettings: ZIO[
      Any,
      AwsError,
      zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly
    ] = AwsError.unwrapOptionField("hlsPlaylistSettings", hlsPlaylistSettings)
    def getManifestName: ZIO[Any, Nothing, __string] = ZIO.succeed(manifestName)
    def getSourceGroup: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ) extends zio.aws.mediatailor.model.RequestOutputItem.ReadOnly {
    override val dashPlaylistSettings
        : Option[zio.aws.mediatailor.model.DashPlaylistSettings.ReadOnly] =
      scala
        .Option(impl.dashPlaylistSettings())
        .map(value =>
          zio.aws.mediatailor.model.DashPlaylistSettings.wrap(value)
        )
    override val hlsPlaylistSettings
        : Option[zio.aws.mediatailor.model.HlsPlaylistSettings.ReadOnly] = scala
      .Option(impl.hlsPlaylistSettings())
      .map(value => zio.aws.mediatailor.model.HlsPlaylistSettings.wrap(value))
    override val manifestName: __string = impl.manifestName(): __string
    override val sourceGroup: __string = impl.sourceGroup(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.RequestOutputItem
  ): zio.aws.mediatailor.model.RequestOutputItem.ReadOnly = new Wrapper(impl)
}
